@@ -12,20 +12,23 @@ from functools import partial
 from PyQt5.Qt import (QPixmap, QSize, QWidget, Qt, pyqtSignal, QUrl, QIcon,
     QPropertyAnimation, QEasingCurve, QApplication, QFontInfo, QAction,
     QSizePolicy, QPainter, QRect, pyqtProperty, QLayout, QPalette, QMenu,
-    QPen, QColor)
+    QPen, QColor, QMimeData)
 from PyQt5.QtWebKitWidgets import QWebView
 
 from calibre import fit_image
 from calibre.gui2.dnd import (dnd_has_image, dnd_get_image, dnd_get_files,
-    IMAGE_EXTENSIONS, dnd_has_extension)
+    dnd_has_extension, image_extensions)
 from calibre.ebooks import BOOK_EXTENSIONS
 from calibre.ebooks.metadata.book.base import (field_metadata, Metadata)
 from calibre.ebooks.metadata.book.render import mi_to_html
 from calibre.gui2 import (config, open_url, pixmap_to_data, gprefs, rating_font, NO_URL_FORMATTING)
 from calibre.utils.config import tweaks
+from calibre.utils.img import image_from_x, blend_image
 from calibre.utils.localization import is_rtl
 
 _css = None
+
+
 def css():
     global _css
     if _css is None:
@@ -35,6 +38,16 @@ def css():
     return _css
 
 
+def copy_all(web_view):
+    web_view = getattr(web_view, 'details', web_view)
+    mf = web_view.page().mainFrame()
+    c = QApplication.clipboard()
+    md = QMimeData()
+    md.setText(mf.toPlainText())
+    md.setHtml(mf.toHtml())
+    c.setMimeData(md)
+
+
 def render_html(mi, css, vertical, widget, all_fields=False, render_data_func=None):  # {{{
     table, comment_fields = (render_data_func or render_data)(mi, all_fields=all_fields,
             use_roman_numbers=config['use_roman_numerals_for_series_number'])
@@ -88,6 +101,7 @@ def render_html(mi, css, vertical, widget, all_fields=False, render_data_func=No
                 % (table, right_pane))
     return ans
 
+
 def get_field_list(fm, use_defaults=False):
     from calibre.gui2.ui import get_gui
     db = get_gui().current_db
@@ -108,6 +122,7 @@ def get_field_list(fm, use_defaults=False):
     available = frozenset(fm.displayable_field_keys())
     return [(f, d) for f, d in fieldlist if f in available]
 
+
 def render_data(mi, use_roman_numbers=True, all_fields=False):
     field_list = get_field_list(getattr(mi, 'field_metadata', field_metadata))
     field_list = [(x, all_fields or display) for x, display in field_list]
@@ -116,6 +131,7 @@ def render_data(mi, use_roman_numbers=True, all_fields=False):
 
 # }}}
 
+
 def details_context_menu_event(view, ev, book_info):  # {{{
     p = view.page()
     mf = p.mainFrame()
@@ -126,6 +142,7 @@ def details_context_menu_event(view, ev, book_info):  # {{{
     for action in list(menu.actions()):
         if action is not ca:
             menu.removeAction(action)
+    menu.addAction(QIcon(I('edit-copy.png')), _('Copy &all'), partial(copy_all, book_info))
     if not r.isNull():
         if url.startswith('format:'):
             parts = url.split(':')
@@ -209,6 +226,7 @@ def details_context_menu_event(view, ev, book_info):  # {{{
         menu.exec_(ev.globalPos())
 # }}}
 
+
 class CoverView(QWidget):  # {{{
 
     cover_changed = pyqtSignal(object, object)
@@ -230,7 +248,7 @@ class CoverView(QWidget):  # {{{
                 QSizePolicy.Expanding if vertical else QSizePolicy.Minimum,
                 QSizePolicy.Expanding)
 
-        self.default_pixmap = QPixmap(I('book.png'))
+        self.default_pixmap = QPixmap(I('default_cover.png'))
         self.pixmap = self.default_pixmap
         self.pwidth = self.pheight = None
         self.data = {}
@@ -368,6 +386,8 @@ class CoverView(QWidget):  # {{{
             pmap.loadFromData(cdata)
         if pmap.isNull():
             return
+        if pmap.hasAlphaChannel():
+            pmap = QPixmap.fromImage(blend_image(image_from_x(pmap)))
         self.pixmap = pmap
         self.do_layout()
         self.update()
@@ -411,6 +431,7 @@ class CoverView(QWidget):  # {{{
 
 # Book Info {{{
 
+
 class BookInfo(QWebView):
 
     link_clicked = pyqtSignal(object)
@@ -441,7 +462,7 @@ class BookInfo(QWebView):
             ('remove_format', 'trash.png'), ('save_format', 'save.png'),
             ('restore_format', 'edit-undo.png'), ('copy_link','edit-copy.png'),
             ('manage_author', 'user_profile.png'), ('compare_format', 'diff.png'),
-            ('set_cover_format', 'book.png'),
+            ('set_cover_format', 'default_cover.png'),
         ]:
             ac = QAction(QIcon(I(icon)), '', self)
             ac.current_fmt = None
@@ -616,6 +637,7 @@ class DetailsLayout(QLayout):  # {{{
 
 # }}}
 
+
 class BookDetails(QWidget):  # {{{
 
     show_book_info = pyqtSignal()
@@ -639,11 +661,10 @@ class BookDetails(QWidget):  # {{{
     open_fmt_with = pyqtSignal(int, object, object)
 
     # Drag 'n drop {{{
-    DROPABBLE_EXTENSIONS = IMAGE_EXTENSIONS+BOOK_EXTENSIONS
 
     def dragEnterEvent(self, event):
         md = event.mimeData()
-        if dnd_has_extension(md, self.DROPABBLE_EXTENSIONS, allow_all_extensions=True) or \
+        if dnd_has_extension(md, image_extensions() + BOOK_EXTENSIONS, allow_all_extensions=True) or \
                 dnd_has_image(md):
             event.acceptProposedAction()
 
@@ -651,7 +672,8 @@ class BookDetails(QWidget):  # {{{
         event.setDropAction(Qt.CopyAction)
         md = event.mimeData()
 
-        x, y = dnd_get_image(md)
+        image_exts = set(image_extensions()) - set(tweaks['cover_drop_exclude'])
+        x, y = dnd_get_image(md, image_exts)
         if x is not None:
             # We have an image, set cover
             event.accept()
@@ -666,7 +688,7 @@ class BookDetails(QWidget):  # {{{
                 return
 
         # Now look for ebook files
-        urls, filenames = dnd_get_files(md, BOOK_EXTENSIONS, allow_all_extensions=True)
+        urls, filenames = dnd_get_files(md, BOOK_EXTENSIONS, allow_all_extensions=True, filter_exts=image_exts)
         if not urls:
             # Nothing found
             return
