@@ -35,6 +35,7 @@ fetched_fields = ('title', 'title_sort', 'authors', 'author_sort', 'series',
                   'series_index', 'languages', 'publisher', 'tags', 'rating',
                   'comments', 'pubdate')
 
+
 class ScrollArea(QScrollArea):
 
     def __init__(self, widget=None, parent=None):
@@ -44,6 +45,7 @@ class ScrollArea(QScrollArea):
         if widget is not None:
             self.setWidget(widget)
 
+
 class MetadataSingleDialogBase(QDialog):
 
     view_format = pyqtSignal(object, object)
@@ -579,11 +581,12 @@ class MetadataSingleDialogBase(QDialog):
         if self.editing_multiple and self.current_row != len(self.row_list) - 1:
             num = len(self.row_list) - 1 - self.current_row
             from calibre.gui2 import question_dialog
+            pm = ngettext('There is another book to edit in this set.',
+                          'There are still {} more books to edit in this set.', num).format(num)
             if not question_dialog(
-                    self, _('Are you sure?'),
-                    _('There are still %d more books to edit in this set.'
+                    self, _('Are you sure?'), pm + _(
                       ' Are you sure you want to stop? Use the Next button'
-                      ' instead of the OK button to move through books in the set.') % num,
+                      ' instead of the OK button to move through books in the set.'),
                     yes_text=_('&Stop editing'), no_text=_('&Continue editing'),
                     yes_icon='dot_red.png', no_icon='dot_green.png',
                     default_yes=False, skip_dialog_name='edit-metadata-single-confirm-ok-on-multiple'):
@@ -658,6 +661,7 @@ class MetadataSingleDialogBase(QDialog):
         # from garbage collecting this dialog
         self.set_current_callback = self.db = None
         self.metadata_before_fetch = None
+
         def disconnect(signal):
             try:
                 signal.disconnect()
@@ -677,6 +681,7 @@ class MetadataSingleDialogBase(QDialog):
 
     # }}}
 
+
 class Splitter(QSplitter):
 
     frame_resized = pyqtSignal(object)
@@ -685,6 +690,7 @@ class Splitter(QSplitter):
         self.frame_resized.emit(ev)
         return QSplitter.resizeEvent(self, ev)
 
+
 class MetadataSingleDialog(MetadataSingleDialogBase):  # {{{
 
     def do_layout(self):
@@ -760,6 +766,7 @@ class MetadataSingleDialog(MetadataSingleDialogBase):  # {{{
         w.l = l = QGridLayout()
         w.setLayout(w.l)
         self.splitter.addWidget(w)
+
         def create_row2(row, widget, button=None, front_button=None):
             row += 1
             ql = BuddyLabel(widget)
@@ -814,6 +821,7 @@ class MetadataSingleDialog(MetadataSingleDialogBase):  # {{{
 
 # }}}
 
+
 class DragTrackingWidget(QWidget):  # {{{
 
     def __init__(self, parent, on_drag_enter):
@@ -825,6 +833,7 @@ class DragTrackingWidget(QWidget):  # {{{
 
 # }}}
 
+
 class MetadataSingleDialogAlt1(MetadataSingleDialogBase):  # {{{
 
     cc_two_column = False
@@ -979,6 +988,7 @@ class MetadataSingleDialogAlt1(MetadataSingleDialogBase):  # {{{
 
 # }}}
 
+
 class MetadataSingleDialogAlt2(MetadataSingleDialogBase):  # {{{
 
     cc_two_column = False
@@ -1116,6 +1126,7 @@ class MetadataSingleDialogAlt2(MetadataSingleDialogBase):  # {{{
 editors = {'default': MetadataSingleDialog, 'alt1': MetadataSingleDialogAlt1,
            'alt2': MetadataSingleDialogAlt2}
 
+
 def edit_metadata(db, row_list, current_row, parent=None, view_slot=None,
         set_current_callback=None, editing_multiple=False):
     cls = gprefs.get('edit_metadata_single_layout', '')
@@ -1137,4 +1148,3 @@ if __name__ == '__main__':
     db = db()
     row_list = list(range(len(db.data)))
     edit_metadata(db, row_list, 0)
-
